### {league:}

Series Wins Series Losses Game Wins Game Losses Standard {std_series_wins:} {std_series_losses:} {std_game_wins:} {std_game_losses:} Doubles {dbl_series_wins:} {dbl_series_losses:} {dbl_game_wins:} {dbl_game_losses:} Role Name Scheduler PLAYERA {player_a_mle_name:} PLAYERB {player_b_mle_name:} PLAYERC {player_c_mle_name:} PLAYERD {player_d_mle_name:} PLAYERE {player_e_mle_name:} PLAYERF {player_f_mle_name:} PLAYERG {player_g_mle_name:} PLAYERH {player_h_mle_name:}